Calibrate simple transfer model
calibrate_simple.RdFits a Bayesian simple transfer model using Stan. The model handles continuous and categorical explanatory variables to predict a response variable.
Arguments
- data
A named list containing the data formatted for the Stan model. Required elements are:
N,M,y,x, andx_sim.- ...
Additional arguments passed to
sampling(e.g.,iter,chains,cores,control).