Plot Habitat Suitability Maps from OCSGE Data
plot_species_habitat.RdGenerates a composite plot of three spatial maps (Global Weight, Foraging Weight, and Resistance) from an `sf` object previously enriched with species traits.
Arguments
- sf_merged
An `sf` object enriched with species traits (e.g., output of
join_ocsge_species).- title_species
Character (optional). The name of the species to display in the title. If NULL, it will try to retrieve the name from the object attributes.